aranha
------

Aranha (pronounced aranya) is a simple web spider written in python using 
gevent for asynchronicity.  Aranha means "spider" in portuguese.

Aranha's goal is to be suitable for projects that need light url fetching
or a simple spidering of a few classes of webpages.  If spidering is a major
part of your project, you probably want to either write your own spider or
use scrapy as a base, as it's much more sophisticated.

